@@ -1,4 +1,4 @@
-/* $Id: board.cc,v 1.92 2003/02/05 19:57:01 bergo Exp $ */
+/* $Id: board.cc,v 1.94 2003/08/17 23:10:09 bergo Exp $ */
 
 /*
 
@@ -63,6 +63,8 @@ Board::Board() : WidgetProxy() {
   FlipInvert=false;
   EditMode=false;
 
+  AnimationTimeout = -1;
+
   for(i=0;i<6;i++)
     info[i].erase();
 
@@ -150,6 +152,8 @@ Board::~Board() {
   gdk_gc_destroy(clkgc);
   gdk_pixmap_unref(clkbar);
   gdk_pixmap_unref(buffer);
+  if (AnimationTimeout >= 0)
+    gtk_timeout_remove(AnimationTimeout);
 }
 
 void Board::reloadFonts() {
@@ -336,6 +340,7 @@ void RootBoard::clockString(int val,char *z) {
 }
 
 void Board::repaint() {
+  global.debug("Board","repaint");
   WidgetProxy::repaint();
 }
 
@@ -693,13 +698,17 @@ void Board::update(bool sndflag) {
 	  if ((!LastMove.size())&&(sndflag))
 	    global.flushSound();
 	  if ((!animes.empty())&&(!gotAnimationLoop)) {
+	    int tag;
 	    gotAnimationLoop=1;
 	    currently_rendered.invalidate();
 	    board_configure_event(yidget,0,(gpointer)this);
 	    if (rate==3)
-	      gtk_timeout_add(global.UseVectorPieces?40:70,board_animate,this);
+	      tag=gtk_timeout_add(global.UseVectorPieces?40:70,
+				  board_animate,this);
 	    else
-	      gtk_timeout_add(global.UseVectorPieces?30:40,board_animate,this);
+	      tag=gtk_timeout_add(global.UseVectorPieces?30:40,
+				  board_animate,this);
+	    AnimationTimeout = tag;
 	  }
 	}
   }
@@ -1216,6 +1225,8 @@ gboolean board_expose_event(GtkWidget *widget,GdkEventExpose *ee,
   unsigned int i;
   int w,h,sq,pw,fw,fh;
 
+  global.debug("Board","board_expose_event");
+
   me=(Board *)data;
   w=ee->area.width;
   h=ee->area.height;
@@ -1340,6 +1351,8 @@ gboolean board_configure_event(GtkWidget *widget,GdkEventConfigure *ce,
 
   me=(Board *)data;
 
+  global.debug("Board","board_configure_event");
+
   gdk_window_get_size(widget->window,&ww,&wh);
   ww-=200;
 
@@ -1383,11 +1396,11 @@ gboolean board_configure_event(GtkWidget *widget,GdkEventConfigure *ce,
   me->sqw = 2*me->borx + 8 * me->sqside + 1;
   me->sqh = 2*me->bory + me->morey + 8 * me->sqside + 1;
 
-  if (global.UseVectorPieces)
-    return 1;
 
-  if ((me->currently_rendered == me->position)&&(!me->update_queue))
+
+  if ((me->currently_rendered == me->position)&&(!me->update_queue)) {
     return 1;
+  }
 
   if (oldsqw!= me->sqw || oldsqh != me->sqh) {
     gdk_pixmap_unref(me->clkbar);
@@ -1405,13 +1418,14 @@ gboolean board_configure_event(GtkWidget *widget,GdkEventConfigure *ce,
 
   memset(me->scrap,0,me->sqw * me->sqh * 3);
 
+  if (global.UseVectorPieces)
+    return 1;
+
   if (me->gotAnimationLoop)
     joker=&(me->fake);
   else
     joker=&(me->position);
 
-  // yes, ugly. pretty != efficient.
-
   me->cur->beginQueueing();
 
   if (me->effectiveFlip())
@@ -1444,6 +1458,7 @@ gboolean board_configure_event(GtkWidget *widget,GdkEventConfigure *ce,
   }
 
   me->currently_rendered=*(joker);
+
   return 1;
 }
 
@@ -1937,6 +1952,7 @@ gboolean vec_board_animate(gpointer data) {
     return TRUE;
   else {
     me->gotAnimationLoop=0;
+    me->AnimationTimeout=-1;
     if (me->update_queue) {
       me->update(me->UpdateStack.top());
       me->UpdateStack.pop();
@@ -2028,6 +2044,7 @@ gboolean board_animate(gpointer data) {
     return TRUE;
   else {
     me->gotAnimationLoop=0;
+    me->AnimationTimeout=-1;
     if (me->update_queue) {
       me->update(me->UpdateStack.top());
       me->UpdateStack.pop();
