@@ -1,10 +1,10 @@
-/* $Id: clock.h,v 1.7 2002/04/18 03:52:19 bergo Exp $ */
+/* $Id: clock.h,v 1.11 2003/06/29 03:17:16 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2003 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -29,31 +29,40 @@
 #include <sys/time.h>
 #include <unistd.h>
 #include <gtk/gtk.h>
+#include <time.h>
 
 #include "stl.h"
 #include "eboard.h"
-#include "time.h"
+#include "widgetproxy.h"
 
 class ClockHost {
  public:
   virtual void updateClock()=0;
 };
 
+// values for getActive()
+#define CLK_WHITE_STOPPED -2
+#define CLK_WHITE_RUNNING -1
+#define CLK_STOPPED        0
+#define CLK_BLACK_RUNNING  1
+#define CLK_BLACK_STOPPED  2
+
 class ChessClock : public UpdateInterface {
  public:
   ChessClock();
-  ~ChessClock();
+  virtual ~ChessClock();
 
-  // activep: -1: white running  0: stopped   1: black running
   void setClock(int whitesec,int blacksec,int activep,int countdown);
   void setHost(ClockHost *hostp);
   void setAnotherHost(ClockHost *hostp);
   void setMirror(ChessClock *dest);
 
-  // -1: white running  0: stopped   1: black running
   int  getActive();
   int  getValue(int black);
 
+  // which= -1=white 0=active one 1=black
+  void incrementClock(int which, int secs);
+
   bool lowTimeWarning(piece mycolor);
 
   void update();
@@ -89,5 +98,48 @@ class ClockMaster {
   friend gint clockmaster_timeout(gpointer data);
 };
 
+#define TCF_GNUCHESS4QUIRK  0x01
+
+class TimeControl {
+ public:  
+  TimeControl();
+  TimeControl &operator=(TimeControl &src);
+  int          operator==(TimeControl &src);
+  int          operator!=(TimeControl &src);
+
+  void fromSerialization(const char *s);
+
+  static void secondsToString(char *dest, int secs, bool units=false);
+  static int  stringToSeconds(char *src);
+
+  void setSecondsPerMove(int seconds);
+  void setIcs(int base /* secs */, int increment /* secs */);
+  void setXMoves(int nmoves, int nsecs);
+
+  bool isRegressive();
+  int  startValue();
+
+  void toXBoard(char *dest, int flags = 0);
+  void toString(char *dest);
+
+  TimeControlMode mode;
+  int value[2];
+};
+
+class TimeControlEditDialog : public ModalDialog {
+ public:
+  TimeControlEditDialog(TimeControl *tc, bool allownone=true);
+  virtual ~TimeControlEditDialog() {}
+  void setUpdateListener(UpdateInterface *ui);
+
+ private:
+  GtkWidget *mi[4], *e[5], *f[3];
+  TimeControl     *src;  
+  TimeControl     local;
+  UpdateInterface *listener;
+
+  friend void tced_ok(GtkWidget *w, gpointer data);
+  friend void tced_dropmenu(GtkMenuItem *w, gpointer data);
+};
 
 #endif
