@@ -1,4 +1,4 @@
-/* $Id: dlg_connect.cc,v 1.12 2002/06/14 17:32:57 bergo Exp $ */
+/* $Id: dlg_connect.cc,v 1.17 2003/02/05 19:57:15 bergo Exp $ */
 
 /*
 
@@ -23,9 +23,7 @@
 
 */
 
-
-
-#include <iostream.h>
+#include <iostream>
 #include <stdlib.h>
 #include <string.h>
 #include "stl.h"
@@ -33,20 +31,20 @@
 #include "protocol.h"
 #include "global.h"
 #include "chess.h"
+#include "eboard.h"
 
 ConnectDialog::ConnectDialog() {
   GtkWidget *v,*hs,*hb,*ok,*cancel,*t;
   GtkWidget *zh,*zv,*ysw,*ysl;
   BoxedLabel *bl[3];
   GList *combo;
-  char z[64];
   int i;
 
   widget=gtk_window_new(GTK_WINDOW_DIALOG);
   //gtk_window_set_transient_for(GTK_WINDOW(dlg),MainWindow);
   if (!global.HostHistory.empty())
     gtk_window_set_default_size(GTK_WINDOW(widget),400,300);
-  gtk_window_set_title(GTK_WINDOW(widget),"Connect to ICS Server");
+  gtk_window_set_title(GTK_WINDOW(widget),_("Connect to ICS Server"));
   gtk_window_set_position(GTK_WINDOW(widget),GTK_WIN_POS_CENTER);
   gtk_container_set_border_width(GTK_CONTAINER(widget),4);
   gtk_widget_realize(widget);
@@ -66,7 +64,7 @@ ConnectDialog::ConnectDialog() {
 				   GTK_POLICY_AUTOMATIC);
 
     ysl=gtk_clist_new(1);
-    gtk_clist_set_column_title(GTK_CLIST(ysl),0,"Recent Hosts");
+    gtk_clist_set_column_title(GTK_CLIST(ysl),0,_("Recent Hosts"));
     gtk_clist_set_selection_mode(GTK_CLIST(ysl),GTK_SELECTION_SINGLE);
     gtk_clist_column_titles_show(GTK_CLIST(ysl));
 
@@ -85,15 +83,14 @@ ConnectDialog::ConnectDialog() {
     gtk_signal_connect(GTK_OBJECT(ysl),"select_row",
 		       GTK_SIGNAL_FUNC(dlgconn_rowsel),this);
 
-    gtk_widget_show(ysl);
-    gtk_widget_show(ysw);
+    Gtk::show(ysl,ysw,0);
   }
 
   gtk_box_pack_start(GTK_BOX(zh),zv,FALSE,TRUE,0);  
 
-  bl[0]=new BoxedLabel("Hostname");
-  bl[1]=new BoxedLabel("TCP Port");
-  bl[2]=new BoxedLabel("Protocol");
+  bl[0]=new BoxedLabel(_("Hostname"));
+  bl[1]=new BoxedLabel(_("TCP Port"));
+  bl[2]=new BoxedLabel(_("Protocol"));
 
   server=gtk_entry_new();
   port=gtk_entry_new();
@@ -115,9 +112,9 @@ ConnectDialog::ConnectDialog() {
 
   gtk_entry_set_text(GTK_ENTRY(port),"5000");
 
-  t=gtk_label_new("Once you connect to a host from this dialog, it will be added to\n"\
+  t=gtk_label_new(_("Once you connect to a host from this dialog, it will be added to\n"\
 		  "the Peer/ICS Bookmarks menu. Edit the ~/.eboard/eboard.conf file\n"\
-		  "to modify or remove entries.");
+		  "to modify or remove entries."));
   gtk_box_pack_start(GTK_BOX(v),t,FALSE,FALSE,6);
 
   hs=gtk_hseparator_new();
@@ -129,9 +126,9 @@ ConnectDialog::ConnectDialog() {
 
   gtk_box_pack_start(GTK_BOX(v),hb,FALSE,FALSE,2);
   
-  ok=gtk_button_new_with_label("Connect");
+  ok=gtk_button_new_with_label(_("Connect"));
   GTK_WIDGET_SET_FLAGS(ok,GTK_CAN_DEFAULT);
-  cancel=gtk_button_new_with_label("Cancel");
+  cancel=gtk_button_new_with_label(_("Cancel"));
   GTK_WIDGET_SET_FLAGS(cancel,GTK_CAN_DEFAULT);
 
   gtk_box_pack_start(GTK_BOX(hb),ok,TRUE,TRUE,0);
@@ -140,19 +137,10 @@ ConnectDialog::ConnectDialog() {
   gtk_widget_grab_default(ok);
 
   for(i=0;i<3;i++)
-    gtk_widget_show(bl[i]->widget);
-  gtk_widget_show(server);
-  gtk_widget_show(port);
-  gtk_widget_show(protocol);
-  gtk_widget_show(t);
-  gtk_widget_show(hs);
-  gtk_widget_show(hb);
-  gtk_widget_show(cancel);
-  gtk_widget_show(ok);
+    gshow(bl[i]->widget);
 
-  gtk_widget_show(zv);
-  gtk_widget_show(zh);
-  gtk_widget_show(v);
+  Gtk::show(server,port,protocol,t,hs,hb,cancel,ok,
+	    zv,zh,v,0);
 
   gtk_signal_connect(GTK_OBJECT(ok),"clicked",
 		     GTK_SIGNAL_FUNC(dlg_connect_ok),this);
@@ -161,7 +149,7 @@ ConnectDialog::ConnectDialog() {
 }
 
 void ConnectDialog::show() {
-  gtk_widget_show(widget);
+  gshow(widget);
   gtk_grab_add(widget);
   gtk_widget_grab_focus(server);
 }
@@ -249,14 +237,13 @@ EditEngineBookmarksDialog::~EditEngineBookmarksDialog() {
 }
 
 EditEngineBookmarksDialog::EditEngineBookmarksDialog(BookmarkListener *updatee) : 
-  ModalDialog("Edit Engine Bookmarks")
+  ModalDialog(N_("Edit Engine Bookmarks"))
 {
-  GtkWidget *v, *v2, *h, *bs, *hs, *hb, *klose, *h2;
+  GtkWidget *v, *v2, *h, *tch, *bs, *hs, *hb, *klose, *h2, *etc;
   BoxedLabel *fl[5];
   int i;
 
   beholder=updatee;
-
   gtk_window_set_default_size(GTK_WINDOW(widget), 550, 300);
 
   v=gtk_vbox_new(FALSE,4);
@@ -272,7 +259,7 @@ EditEngineBookmarksDialog::EditEngineBookmarksDialog(BookmarkListener *updatee)
 				 GTK_POLICY_AUTOMATIC);
 
   bl=gtk_clist_new(1);
-  gtk_clist_set_column_title(GTK_CLIST(bl),0,"Engine Bookmarks");
+  gtk_clist_set_column_title(GTK_CLIST(bl),0,_("Engine Bookmarks"));
   gtk_clist_set_selection_mode(GTK_CLIST(bl),GTK_SELECTION_SINGLE);
   gtk_clist_column_titles_show(GTK_CLIST(bl));
 
@@ -284,27 +271,37 @@ EditEngineBookmarksDialog::EditEngineBookmarksDialog(BookmarkListener *updatee)
   v2=gtk_vbox_new(FALSE,2);
   gtk_box_pack_start(GTK_BOX(h), v2, FALSE, TRUE, 4);
 
-  fl[0]=new BoxedLabel("Bookmark Caption:");
-  fl[1]=new BoxedLabel("Directory:");
-  fl[2]=new BoxedLabel("Command Line:");
-  fl[3]=new BoxedLabel("Secs per move:");
-  fl[4]=new BoxedLabel("Max Ply:");
+  fl[0]=new BoxedLabel(_("Bookmark Caption:"));
+  fl[1]=new BoxedLabel(_("Directory:"));
+  fl[2]=new BoxedLabel(_("Command Line:"));
+  fl[3]=new BoxedLabel(_("Time Control:"));
+  fl[4]=new BoxedLabel(_("Max Ply:"));
   
   fe[0]=gtk_entry_new();
   fe[1]=gtk_entry_new();
   fe[2]=gtk_entry_new();
-  fe[3]=gtk_entry_new();
+  fe[3]=gtk_label_new(" ");
   fe[4]=gtk_entry_new();
 
-  fe[5]=gtk_check_button_new_with_label("Human plays white");
-  fe[6]=gtk_check_button_new_with_label("Think Always");
+  tch = gtk_hbox_new(FALSE,4);
 
-  uf[0]=new BoxedLabel("Variant:");
-  uf[1]=new BoxedLabel("Engine Type:");
+  edittc = etc = gtk_button_new_with_label(_("Change..."));
+
+  fe[5]=gtk_check_button_new_with_label(_("Human plays white"));
+  fe[6]=gtk_check_button_new_with_label(_("Think Always"));
+
+  uf[0]=new BoxedLabel(_("Variant:"));
+  uf[1]=new BoxedLabel(_("Engine Type:"));
 
   for(i=0;i<5;i++) {
     gtk_box_pack_start(GTK_BOX(v2), fl[i]->widget, FALSE,TRUE, 2);
-    gtk_box_pack_start(GTK_BOX(v2), fe[i], FALSE,TRUE, 0);
+    if (i!=3)
+      gtk_box_pack_start(GTK_BOX(v2), fe[i], FALSE,TRUE, 0);
+    else {
+      gtk_box_pack_start(GTK_BOX(v2), tch, FALSE,TRUE, 0);
+      gtk_box_pack_start(GTK_BOX(tch), fe[3], FALSE, TRUE, 0);
+      gtk_box_pack_end(GTK_BOX(tch), etc, FALSE, TRUE, 0);
+    }
   }
 
   for(i=5;i<7;i++)
@@ -312,14 +309,12 @@ EditEngineBookmarksDialog::EditEngineBookmarksDialog(BookmarkListener *updatee)
 
   for(i=0;i<2;i++)
     gtk_box_pack_start(GTK_BOX(v2), uf[i]->widget, FALSE,TRUE, 2);    
-
-  
-
+ 
   h2=gtk_hbox_new(FALSE,4);
 
-  apply=gtk_button_new_with_label("Apply Changes");
-  rm=gtk_button_new_with_label("Delete This Entry");
-  rmall=gtk_button_new_with_label("Delete All Entries");
+  apply=gtk_button_new_with_label(_("Apply Changes"));
+  rm=gtk_button_new_with_label(_("Delete This Entry"));
+  rmall=gtk_button_new_with_label(_("Delete All Entries"));
 
   gtk_box_pack_start(GTK_BOX(v2),h2,FALSE,TRUE,2);
   gtk_box_pack_end(GTK_BOX(h2),apply,FALSE,TRUE,4);
@@ -337,36 +332,23 @@ EditEngineBookmarksDialog::EditEngineBookmarksDialog(BookmarkListener *updatee)
 
   gtk_box_pack_start(GTK_BOX(v),hb,FALSE,FALSE,2);
   
-  klose=gtk_button_new_with_label("Close");
+  klose=gtk_button_new_with_label(_("Close"));
   GTK_WIDGET_SET_FLAGS(klose,GTK_CAN_DEFAULT);
 
   gtk_box_pack_start(GTK_BOX(hb),klose,TRUE,TRUE,0);
 
   gtk_widget_grab_default(klose);
 
-  gtk_widget_show(klose);
-  gtk_widget_show(hb);
-  gtk_widget_show(hs);
-
-  gtk_widget_show(h2);
-  gtk_widget_show(apply);
-  gtk_widget_show(rm);
-  gtk_widget_show(rmall);
-
-  gtk_widget_show(v2);
+  Gtk::show(etc,tch,klose,hb,hs,h2,apply,rm,rmall,v2,0);
 
   for(i=0;i<7;i++)
-    gtk_widget_show(fe[i]);
+    gshow(fe[i]);
   for(i=0;i<5;i++)
-    gtk_widget_show(fl[i]->widget);
+    gshow(fl[i]->widget);
   for(i=0;i<2;i++)
     uf[i]->show();
 
-  gtk_widget_show(bl);
-  gtk_widget_show(bs);
-  gtk_widget_show(h);
-  gtk_widget_show(v);
-
+  Gtk::show(bl,bs,h,v,0);
   setDismiss(GTK_OBJECT(klose),"clicked");
 
   refresh();
@@ -381,6 +363,7 @@ EditEngineBookmarksDialog::EditEngineBookmarksDialog(BookmarkListener *updatee)
 
   gtk_widget_set_sensitive(rm,FALSE);
   gtk_widget_set_sensitive(apply,FALSE);
+  gtk_widget_set_sensitive(edittc,FALSE);
 
   gtk_signal_connect(GTK_OBJECT(rm),"clicked",
 		     GTK_SIGNAL_FUNC(eebmd_rm1), (gpointer) this);
@@ -390,6 +373,9 @@ EditEngineBookmarksDialog::EditEngineBookmarksDialog(BookmarkListener *updatee)
 
   gtk_signal_connect(GTK_OBJECT(apply),"clicked",
 		     GTK_SIGNAL_FUNC(eebmd_apply), (gpointer) this);
+
+  gtk_signal_connect(GTK_OBJECT(etc),"clicked",
+		     GTK_SIGNAL_FUNC(eebmd_edittc), (gpointer) this);
 }
 
 void EditEngineBookmarksDialog::refresh() {
@@ -415,6 +401,10 @@ void EditEngineBookmarksDialog::refresh() {
 
 }
 
+void EditEngineBookmarksDialog::update() {
+  updateRightPane();
+}
+
 void EditEngineBookmarksDialog::updateRightPane() {
   list<EngineBookmark *>::iterator ei;
   int i;
@@ -429,47 +419,48 @@ void EditEngineBookmarksDialog::updateRightPane() {
     gtk_entry_set_text(GTK_ENTRY(fe[1]),(*ei)->directory.c_str());
     gtk_entry_set_text(GTK_ENTRY(fe[2]),(*ei)->cmdline.c_str());
 
-    sprintf(z,"%d",(*ei)->secspermove);
-    gtk_entry_set_text(GTK_ENTRY(fe[3]),z);
+    localtc.toString(z);
+    gtk_label_set_text(GTK_LABEL(fe[3]),z);
+    gtk_widget_queue_resize(fe[3]);
 
     sprintf(z,"%d",(*ei)->maxply);
     gtk_entry_set_text(GTK_ENTRY(fe[4]),z);
 
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fe[5]),
-				 (*ei)->humanwhite?TRUE:FALSE);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fe[6]),
-				 (*ei)->think?TRUE:FALSE);
+    gtset(GTK_TOGGLE_BUTTON(fe[5]),(*ei)->humanwhite?TRUE:FALSE);
+    gtset(GTK_TOGGLE_BUTTON(fe[6]),(*ei)->think?TRUE:FALSE);
 
-    sprintf(z,"Variant: %s (uneditable)", ChessGame::variantName( (*ei)->mode ) );
+    sprintf(z,_("Variant: %s (uneditable)"), ChessGame::variantName( (*ei)->mode ) );
     uf[0]->setText(z);
 
     switch( (*ei)->proto ) {
-    case 0: strcpy(x,"generic xboard v2"); break;
+    case 0: strcpy(x,_("generic xboard v2")); break;
     case 1: strcpy(x,"crafty"); break;
     case 2: strcpy(x,"sjeng"); break;
     case 3: strcpy(x,"GNU chess 4.x"); break;
     }
 
-    sprintf(z,"Engine Type: %s (uneditable)",x);
+    sprintf(z,_("Engine Type: %s (uneditable)"),x);
     uf[1]->setText(z);
 
     gtk_widget_set_sensitive(rm,TRUE);
     gtk_widget_set_sensitive(apply,TRUE);
+    gtk_widget_set_sensitive(edittc,TRUE);
 
   } else {
     gtk_entry_set_text(GTK_ENTRY(fe[0]),"\0");
     gtk_entry_set_text(GTK_ENTRY(fe[1]),"\0");
     gtk_entry_set_text(GTK_ENTRY(fe[2]),"\0");
-    gtk_entry_set_text(GTK_ENTRY(fe[3]),"\0");
+    gtk_label_set_text(GTK_LABEL(fe[3])," ");
     gtk_entry_set_text(GTK_ENTRY(fe[4]),"\0");
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fe[5]),0);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fe[6]),0);
+    gtset(GTK_TOGGLE_BUTTON(fe[5]),0);
+    gtset(GTK_TOGGLE_BUTTON(fe[6]),0);
 
-    uf[0]->setText("Variant:");
-    uf[1]->setText("Engine Type:");
+    uf[0]->setText(_("Variant:"));
+    uf[1]->setText(_("Engine Type:"));
 
     gtk_widget_set_sensitive(rm,FALSE);
     gtk_widget_set_sensitive(apply,FALSE);
+    gtk_widget_set_sensitive(edittc,FALSE);
   }
 }
 
@@ -477,8 +468,14 @@ void
 eebmd_rowsel(GtkCList *clist,int row,int column,GdkEventButton *eb,
 	     gpointer data)
 {
-  EEBMDp me;
-  me=(EEBMDp) data;
+  EEBMDp me = (EEBMDp) data;
+  list<EngineBookmark *>::iterator ei;
+  int i;
+
+  ei=global.EnginePresets.begin();
+  for(i=row;i;i--)
+    ei++;  
+  me->localtc = (*ei)->timecontrol;
 
   me->selindex=row;
   me->updateRightPane();
@@ -537,6 +534,19 @@ eebmd_rmall(GtkWidget *w, gpointer data)
   me->updateRightPane();
 }
 
+void 
+eebmd_edittc(GtkWidget *w, gpointer data) {
+  EEBMDp me = (EEBMDp) data;
+  TimeControlEditDialog *tced;
+
+  if (me->selindex < 0)
+    return;
+
+  tced = new TimeControlEditDialog(&(me->localtc));
+  tced->setUpdateListener( (UpdateInterface *) me );
+  tced->show();
+}
+
 void
 eebmd_apply(GtkWidget *w, gpointer data)
 {
@@ -555,7 +565,7 @@ eebmd_apply(GtkWidget *w, gpointer data)
   (*ei)->caption     = gtk_entry_get_text(GTK_ENTRY(me->fe[0]));
   (*ei)->directory   = gtk_entry_get_text(GTK_ENTRY(me->fe[1]));
   (*ei)->cmdline     = gtk_entry_get_text(GTK_ENTRY(me->fe[2]));
-  (*ei)->secspermove = atoi(gtk_entry_get_text(GTK_ENTRY(me->fe[3])));
+  (*ei)->timecontrol = me->localtc;
   (*ei)->maxply      = atoi(gtk_entry_get_text(GTK_ENTRY(me->fe[4])));
 
   (*ei)->think = (*ei)->humanwhite=0;
