@@ -1,4 +1,4 @@
-/* $Id: dlg_prefs.cc,v 1.35 2003/07/06 18:17:36 bergo Exp $ */
+/* $Id: dlg_prefs.cc,v 1.36 2003/11/22 04:55:28 bergo Exp $ */
 
 /*
 
@@ -62,9 +62,14 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   GtkWidget *icv, *icl, *ict1, *icl1, *ifr1, *ifr2, *ifv1, *ifv2, *icl2, *icl3;
 
   // -- sound
-  static char *zcaption[]={N_("Opponent Moved"),N_("Draw Offered"),N_("Private Tell"),
-			   N_("ICS Challenge"),N_("Time Running Out"),
-                           N_("Game Won"), N_("Game Lost"), N_("Game Started"),
+  static char *zcaption[]={N_("Opponent Moved"),
+			   N_("Draw Offered"),
+			   N_("Private Tell"),
+			   N_("ICS Challenge"),
+			   N_("Time Running Out"),
+                           N_("Game Won"), 
+			   N_("Game Lost"), 
+			   N_("Game Started"),
                            N_("Obs'vd Game Ended"), 
 			   N_("Move made (Obs'vd/Exm'd Games)") };
 
@@ -186,8 +191,8 @@ PreferencesDialog::PreferencesDialog() : ModalDialog(N_("Preferences")) {
   gtk_box_pack_start(GTK_BOX(icv),autologb,FALSE,FALSE,2);
 
   /*
-  allob[0]=gtk_check_button_new_with_label(_("Show observers on played games"));
-  allob[1]=gtk_check_button_new_with_label(_("Show observers on observed games"));
+  allob[0]=gtk_check_button_new_with_label(FIXTRAN("Show observers on played games"));
+  allob[1]=gtk_check_button_new_with_label(FIXTRAN("Show observers on observed games"));
 
   gtk_box_pack_start(GTK_BOX(icv),allob[0],FALSE,FALSE,2);
   gtk_box_pack_start(GTK_BOX(icv),allob[1],FALSE,FALSE,2);
