@@ -1,4 +1,4 @@
-/* $Id: eboard.h,v 1.41 2003/07/06 18:17:36 bergo Exp $ */
+/* $Id: eboard.h,v 1.42 2003/11/14 01:59:42 bergo Exp $ */
 
 /*
 
@@ -23,11 +23,10 @@
 
 */
 
-
-
 #ifndef EBOARD_H
 #define EBOARD_H 1
 
+#include <iostream>
 #include <gtk/gtk.h>
 #include "config.h"
 
@@ -209,16 +208,13 @@ typedef enum {
 /* i18n placeholders in case gettext isn't available*/
 
 #ifdef ENABLE_NLS
-  #include <libintl.h>
-  #include <locale.h>
-  #define _(s) gettext(s)
+  #include "langs.h"
+  #define _(s) langs_translate(s)
   #define N_(s) (s)
-  #define eboard_gettext(s) gettext(s)
+  #define eboard_gettext(s) langs_translate(s)
 #else
   #define _(s) (s)
   #define N_(s) (s)
-  #define textdomain(Domain)
-  #define bindtextdomain(Package, Directory)
   #define eboard_gettext(x) (x)
 #endif
 
