@@ -1,4 +1,4 @@
-/* $Id: global.h,v 1.61 2002/06/26 01:06:59 bergo Exp $ */
+/* $Id: global.h,v 1.72 2003/07/03 19:47:53 bergo Exp $ */
 
 /*
 
@@ -37,6 +37,7 @@
 #include "seekgraph.h"
 #include "history.h"
 #include "bugpane.h"
+#include "clock.h"
 #include "stl.h"
 
 class Board;
@@ -70,15 +71,15 @@ class EngineBookmark {
   int operator==(EngineBookmark *ebm);
   void read(tstring &t);
 
-  string  caption;
-  string  directory;
-  string  cmdline;
-  int     humanwhite;
-  int     secspermove;
-  int     maxply;
-  int     think;  
-  int     proto;
-  variant mode;
+  string      caption;
+  string      directory;
+  string      cmdline;
+  int         humanwhite;
+  TimeControl timecontrol;
+  int         maxply;
+  int         think;  
+  int         proto;
+  variant     mode;
 
 };
 
@@ -105,12 +106,15 @@ class IcsChannel {
 
 class ChannelSplitter : public SigChildHandler
 {
- public:  
-  void appendToChannel(int ch,char *msg,int color,Importance im=IM_NORMAL); 
+ public:
+  virtual ~ChannelSplitter() {}
+  void appendToChannel(int ch,char *msg,int color,Importance im=IM_NORMAL);
   virtual Notebook * getNotebook()=0;
 
   void removeRemovablePage(int n);
   void getChannels(char *ipaddr);
+  void channelPageUp(int ch);
+  void channelPageDown(int ch);
 
   void ZombieNotification(int pid);
 
@@ -175,23 +179,13 @@ class Desktop {
 
 
   WindowGeometry wMain, wGames, wLocal, wAds;
+  int PanePosition;
 
  private:
   vector<WindowGeometry *> consoles;
   vector<string *> cfilters;
 };
 
-class ObjectCounter {
- public:
-  void create(const char * k);
-  void destroy(const char * k);
-  void report();
- private:
-  int getIndex(const char *k);  
-  vector<string> names;
-  vector<int>    N, T;
-};
-
 class Environment {
  public:
   Environment();
@@ -201,11 +195,11 @@ class Environment {
   string Config;
 };
 
-class Global : public ChannelSplitter,
-	       public ObjectCounter
+class Global : public ChannelSplitter
 {
  public:
   Global();
+  virtual ~Global() {}
   
   ChessGame * getGame(int num);
   void removeBoard(Board *b);
@@ -240,11 +234,17 @@ class Global : public ChannelSplitter,
   void agentBroadcast(char *z);
   int  receiveAgentLine(char *dest,int limit);
 
+  /* issue sound events */
   void opponentMoved();
   void drawOffered();
   void privatelyTold();
   void challenged();
   void timeRunningOut();
+  void gameWon();
+  void gameLost();
+  void gameStarted();
+  void gameFinished();
+  void moveMade();
 
   void flushSound();
   void setPasswordMode(int pm);
@@ -298,6 +298,7 @@ class Global : public ChannelSplitter,
   GtkWidget          *mainpaned;
   GtkWidget          *toplevelwidget;
   BugPane            *bugpane;
+  IONotificationInterface *iowatcher;
 
   StringCollection   annotator;
   SoundSlave         sndslave;
@@ -318,6 +319,7 @@ class Global : public ChannelSplitter,
   char PlayerFont[96];
   char InfoFont[96];
   char ConsoleFont[96];
+  char SeekFont[96];
 
   int PlainSquares;
   int LightSqColor;
@@ -350,11 +352,19 @@ class Global : public ChannelSplitter,
   bool PopupHelp;
   int LowTimeWarningLimit;
   int SmootherAnimation;
+  int IcsAllObPlayed;
+  int IcsAllObObserved;
+
+  char P2PName[64];
 
   TerminalColor Colors;
   Desktop Desk;
   
   // 0=opponent moved, 1=draw offer 2=pvt tell 3=challenged
+  // 4=time running out
+  // 5=won game        6=lost game  7=game started
+  // 8=game over (observed)
+  // 9=moved (observed)
   SoundEvent sndevents[N_SOUND_EVENTS];
 
   int CommLog;
@@ -382,6 +392,8 @@ class Global : public ChannelSplitter,
   void renumberGame(ChessGame *cg,int id);
   void clearDupes(ChessGame *cg);
 
+  void playOther(int i);
+
   int MainLevel;
   int QuitPending;
 
