@@ -1,4 +1,4 @@
-/* $Id: history.h,v 1.1 2001/06/29 22:27:39 bergo Exp $ */
+/* $Id: history.h,v 1.2 2002/09/10 19:08:28 bergo Exp $ */
 
 /*
 
@@ -29,7 +29,7 @@
 
 class History {
  public:
-  History(int len);
+  History(unsigned int len);
 
   typedef list<char *>::iterator iterator;
 
@@ -41,7 +41,7 @@ class History {
   iterator getCursor();
   
  private:
-  int Length;
+  unsigned int Length;
   list<char *> thehistory;
   iterator cursor;
 };
