@@ -1,4 +1,4 @@
-/* $Id: mainwindow.cc,v 1.114 2003/07/06 18:17:36 bergo Exp $ */
+/* $Id: mainwindow.cc,v 1.118 2003/11/22 04:55:29 bergo Exp $ */
 
 /*
 
@@ -36,9 +36,7 @@
 #include "global.h"
 #include "p2p.h"
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "icon-eboard.xpm"
 
@@ -174,7 +172,7 @@ MainWindow::MainWindow() {
   mag=gtk_accel_group_new();
   gif=gtk_item_factory_new(GTK_TYPE_MENU_BAR, "<main>", mag);
 
-#ifdef HAVE_GETTEXT
+#ifdef ENABLE_NLS
   gtk_item_factory_set_translate_func(gif,(GtkTranslateFunc) gtkgettext, 0, 0);
 #endif
 
@@ -779,7 +777,7 @@ void MainWindow::searchThemes() {
     }
     global.setPieceSet(Themes.front()->Filename,true,true);
   } else {
-    s="basic_w.png";
+    s="classic.png";
     global.setPieceSet(s,true,true);
   }
 }
@@ -788,8 +786,8 @@ void MainWindow::greet() {
   char z[128];
   sprintf (z,_("eboard version %s (%s)"),global.Version,global.SystemType);
   icsout->append(z,0xc0ff00,IM_IGNORE);
-  icsout->append(_("(c) 2001-2002 Felipe Bergo <bergo@seul.org> (FICS Handle: Pulga)"),
-		 0xc0ff00,IM_IGNORE);
+  sprintf (z,_("(c) 2000-%d Felipe Bergo <bergo@seul.org> (FICS handle: Pulga)"), 2003);
+  icsout->append(z,0xc0ff00,IM_IGNORE);
   icsout->append(_("Distributed under the terms of the GNU General Public License, version 2 or later"),0xffc000,IM_IGNORE);
   icsout->append("http://www.gnu.org/copyleft/gpl.html",0xffc000,IM_IGNORE);
   icsout->append(_("Source code available at http://eboard.sourceforge.net"),0xc0ff00,IM_IGNORE);
@@ -1105,17 +1103,18 @@ void MainWindow::cleanUpConnection() {
   list<Board *>::iterator bli;
   global.debug("MainWindow","cleanUpConnection");
   setSealPix(0);
+
+  if (global.protocol) {
+    global.protocol->finalize();
+    delete global.protocol;
+    global.protocol=0;
+  }
   if (global.network) {
     global.network->close();
     delete global.network;
     global.network=0;    
     icsout->append(_("--- Disconnected"),0xc0ff00);
   }
-  if (global.protocol) {
-    global.protocol->finalize();
-    delete global.protocol;
-    global.protocol=0;
-  }
 
   // stop all clocks
   for(bli=global.BoardList.begin();bli!=global.BoardList.end();bli++)
@@ -1652,6 +1651,10 @@ void MainWindow::readAvailable(int handle) {
       ++loopc;
       if (loopc%10 == 9)
 	gtk_main_iteration();
+
+      if ( (global.network==0) || (global.protocol==0) )
+	break;
+
     } while(gotinput);
 
   } else { /* got input from an agent (script) */
@@ -1938,7 +1941,8 @@ void InputModeSelector::setChatMode(bool m) {
   string x;
   ChatMode=m;
 
-  x=m?_("[chat]"):_("[cmd]");
+  x=m?_("[chat]"):
+      _("[cmd]");
   gtk_label_set_text(GTK_LABEL(l[0]), x.c_str());
 
   if (m) {
