@@ -1,4 +1,4 @@
-/* $Id: movelist.cc,v 1.11 2002/04/28 21:04:34 bergo Exp $ */
+/* $Id: movelist.cc,v 1.15 2003/01/19 19:24:02 bergo Exp $ */
 
 /*
 
@@ -23,13 +23,14 @@
 
 */
 
-#include <iostream.h>
+#include <iostream>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include "movelist.h"
 #include "tstring.h"
 #include "stl.h"
+#include "eboard.h"
 
 #include "icon-moves.xpm"
 
@@ -43,7 +44,7 @@ MoveListWindow::MoveListWindow(char *p1,char *p2,
   listener=0;
 
   if (gid<7000)  
-    sprintf(z,"Game #%d - %s vs. %s",gid,p1,p2);
+    sprintf(z,_("Game #%d - %s vs. %s"),gid,p1,p2);
   else
     sprintf(z,"%s vs. %s",p1,p2);
   
@@ -61,8 +62,8 @@ MoveListWindow::MoveListWindow(char *p1,char *p2,
   gtk_clist_set_shadow_type(GTK_CLIST(clist),GTK_SHADOW_IN);
   gtk_clist_set_selection_mode(GTK_CLIST(clist),GTK_SELECTION_SINGLE);
   gtk_clist_set_column_title(GTK_CLIST(clist),0,"#");
-  gtk_clist_set_column_title(GTK_CLIST(clist),1,"White");
-  gtk_clist_set_column_title(GTK_CLIST(clist),2,"Black");
+  gtk_clist_set_column_title(GTK_CLIST(clist),1,_("White"));
+  gtk_clist_set_column_title(GTK_CLIST(clist),2,_("Black"));
   gtk_clist_column_titles_passive(GTK_CLIST(clist));
   gtk_clist_column_titles_show(GTK_CLIST(clist));
 
@@ -77,13 +78,11 @@ MoveListWindow::MoveListWindow(char *p1,char *p2,
   textbar->show();
   gtk_box_pack_start(GTK_BOX(v),textbar->widget,FALSE,TRUE,0);
 
-  setIcon(icon_moves_xpm,"Moves");
+  setIcon(icon_moves_xpm,_("Moves"));
 
   populate_clist(moves,over,result,reason);
 
-  gtk_widget_show(clist);
-  gtk_widget_show(sw);
-  gtk_widget_show(v);
+  Gtk::show(clist,sw,v,0);
 
   gtk_signal_connect (GTK_OBJECT (widget), "destroy",
 		      GTK_SIGNAL_FUNC (movelist_destroy), this);
@@ -95,8 +94,8 @@ MoveListWindow::~MoveListWindow() {
 }
 
 void MoveListWindow::updateList(list<Position> &moves,
-				int over=0,GameResult result=UNDEF,
-				char *reason=0) {
+				int over,GameResult result,
+				char *reason) {
   populate_clist(moves,over,result,reason);
 }
 
@@ -125,8 +124,8 @@ void MoveListWindow::populate_clist(list<Position> &moves, int over,
     if (tm!=cm) {
       sprintf(z,"%d",tm);
       zz[0]=z;
-      zz[1]="none";
-      zz[2]="none";
+      zz[1]=_("none");
+      zz[2]=_("none");
       gtk_clist_append(GTK_CLIST(clist),zz);
       ++i;      
       cm=tm;
@@ -155,7 +154,7 @@ void MoveListWindow::populate_clist(list<Position> &moves, int over,
     strcat(z,reason);
     textbar->setText(z);
   } else {
-    textbar->setText("Game in progress.");
+    textbar->setText(_("Game in progress."));
   }
 
   gtk_clist_set_column_width(GTK_CLIST(clist),0,32);
