@@ -1,4 +1,4 @@
-/* $Id: network.cc,v 1.41 2003/07/03 19:47:53 bergo Exp $ */
+/* $Id: network.cc,v 1.42 2003/11/15 03:17:58 bergo Exp $ */
 
 /*
 
@@ -335,8 +335,7 @@ int DirectConnection::open() {
 
   netsocket=socket(AF_INET,SOCK_STREAM,0);
 
-#ifndef USE_NO_TCP_OPTIONS
-
+#ifdef USE_SOCK_OPTS
   int nagle=1;
 
   #ifdef USE_SOL_TCP
@@ -344,7 +343,6 @@ int DirectConnection::open() {
   #elif defined USE_IPPROTO_TCP
     setsockopt(netsocket,IPPROTO_TCP,TCP_NODELAY,&nagle,sizeof(nagle));
   #endif
-
 #endif
 
   sa.sin_family=he->h_addrtype;
