@@ -1,4 +1,4 @@
-/* $Id: notebook.cc,v 1.19 2002/06/26 01:06:59 bergo Exp $ */
+/* $Id: notebook.cc,v 1.25 2003/06/28 05:25:45 bergo Exp $ */
 
 /*
 
@@ -23,7 +23,7 @@
 
 */
 
-#include <iostream.h>
+#include <iostream>
 #include "eboard.h"
 #include "global.h"
 #include "notebook.h"
@@ -45,10 +45,10 @@ Page::Page() {
   naughty=false;
   level=IM_ZERO;
   label=gtk_label_new("<none>");
-  gtk_widget_show(label);
+  gshow(label);
 }
 
-Page::Page(int _number,GtkWidget *_content, char *_title, bool _removable=false) {
+Page::Page(int _number,GtkWidget *_content, char *_title, bool _removable) {
   
   GtkWidget *b,*p;
 
@@ -76,10 +76,7 @@ Page::Page(int _number,GtkWidget *_content, char *_title, bool _removable=false)
     label=gtk_label_new(title);
     gtk_box_pack_start(GTK_BOX(labelframe), label, FALSE, TRUE, 1);
 
-    gtk_widget_show(p);
-    gtk_widget_show(b);
-    gtk_widget_show(label);
-    gtk_widget_show(labelframe);
+    Gtk::show(p,b,label,labelframe,0);
 
     gtk_signal_connect(GTK_OBJECT(b),"clicked",
 		       GTK_SIGNAL_FUNC(page_trash), (gpointer) this);
@@ -87,11 +84,10 @@ Page::Page(int _number,GtkWidget *_content, char *_title, bool _removable=false)
   } else {
 
     label=gtk_label_new(title);
-    gtk_widget_show(label);
+    gshow(label);
     labelframe=label;
 
   }
-
 }
 
 int Page::operator==(int n) {
@@ -135,7 +131,7 @@ void Page::dump() {
   cerr.setf(ios::dec,ios::basefield);
   cerr << "pageid=" << number << " ";
   cerr << "title=" << title << " ";
-  cerr << "level=" << level << endl;
+  cerr << "level=" << ((int)level) << endl;
 }
 
 GdkPixmap * Notebook::trashface=0;
@@ -166,7 +162,7 @@ Notebook::Notebook() {
 		     (gpointer)this);
 }
 
-void Notebook::addPage(GtkWidget *what,char *title,int id,bool removable=false) {
+void Notebook::addPage(GtkWidget *what,char *title,int id,bool removable) {
   Page *pg;
   global.debug("Notebook","addPage",title);
   pg=new Page(id,what,title,removable);
@@ -192,20 +188,19 @@ void Notebook::removePage(int id) {
     }  
 }
 
-int Notebook::getCurrentPage() {
-  return(gtk_notebook_get_current_page(GTK_NOTEBOOK(widget)));
+unsigned int Notebook::getCurrentPage() {
+  return((unsigned int)gtk_notebook_get_current_page(GTK_NOTEBOOK(widget)));
 }
 
 int Notebook::getCurrentPageId() {
-  vector<Page *>::iterator pi;
-  int i;
+  unsigned int i;
   i=getCurrentPage();
   if (i >= pages.size())
     return 0;
   return( pages[i]->number );
 }
 
-void Notebook::setTabColor(int pageid,int color,Importance imp=IM_TOP) {
+void Notebook::setTabColor(int pageid,int color,Importance imp) {
   vector<Page *>::iterator pi;
   int i;
   global.debug("Notebook","setTabColor","1");
@@ -217,7 +212,7 @@ void Notebook::setTabColor(int pageid,int color,Importance imp=IM_TOP) {
 }
 
 void Notebook::setTabColor(int page_num,int color,int poly,
-			   Importance imp=IM_TOP) {
+			   Importance imp) {
   vector<Page *>::iterator pi;
   GdkColor nc;
   GtkStyle *style;
@@ -236,12 +231,13 @@ void Notebook::setTabColor(int page_num,int color,int poly,
   nc.red=((color>>16)<<8);
   nc.green=(color&0x00ff00);
   nc.blue=((color&0xff)<<8);
-  style=gtk_style_new();
+  style=gtk_style_copy( gtk_widget_get_style((*pi)->label) );
 
   for(i=0;i<5;i++)
     style->fg[i]=nc;
 
   gtk_widget_set_style( (*pi)->label, style );
+  gtk_widget_ensure_style( (*pi)->label );
   gtk_widget_queue_draw( (*pi)->label );
 }
 
@@ -304,6 +300,15 @@ void Notebook::getNaughty(vector<int> &evil_ids) {
       evil_ids.push_back( (*i)->number );
 }
 
+bool Notebook::isNaughty(int pageid) {
+  vector<Page *>::iterator i;
+  for(i=pages.begin();i!=pages.end();i++)
+    if ( (*i)->number == pageid )
+      if ((*i)->naughty)
+	return true;
+  return false;
+}
+
 bool Notebook::hasNaughty() {
   vector<Page *>::iterator i;
   for(i=pages.begin();i!=pages.end();i++)
@@ -332,9 +337,7 @@ void Notebook::addBombToTab(Page *pg) {
   gtk_box_pack_start(GTK_BOX(hb),label,FALSE,FALSE,4);
   gtk_box_pack_start(GTK_BOX(hb),pm,FALSE,FALSE,4);
 
-  gtk_widget_show(label);
-  gtk_widget_show(pm);
-  gtk_widget_show(hb);
+  Gtk::show(label,pm,hb,0);
   
   pg->label=label;
   gtk_notebook_set_tab_label(GTK_NOTEBOOK(widget),pg->content,hb);
@@ -351,10 +354,11 @@ notebook_switch_page(GtkNotebook *notebook,
 		     gint page_num,
 		     gpointer data) {
   Notebook *me;
+  unsigned int pg = (unsigned int) page_num;
   me=(Notebook *)data;
-  me->setTabColor(page_num,0,0,IM_RESET);
-  if ( (me->pcl) && (me->pages.size() > page_num) )
-    me->pcl->paneChanged(page_num, me->pages[page_num]->number);
+  me->setTabColor(pg,0,0,IM_RESET);
+  if ( (me->pcl) && (me->pages.size() > pg) )
+    me->pcl->paneChanged(pg, me->pages[pg]->number);
 }
 
 // ================================================================
@@ -388,6 +392,9 @@ void NotebookInsider::contentUpdated() {
     case IM_PERSONAL:
       color=0x0000ff;
       break;
+    default:
+      color=0x00ff00; /* will never happen */
+      break;
     }
   }
   if (!mynotebook)
