@@ -1,4 +1,4 @@
-/* $Id: pieces.cc,v 1.29 2002/06/17 03:24:31 bergo Exp $ */
+/* $Id: pieces.cc,v 1.34 2003/01/19 19:24:03 bergo Exp $ */
 
 /*
 
@@ -23,7 +23,7 @@
 
 */
 
-#include <iostream.h>
+#include <iostream>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -34,6 +34,7 @@
 #include "pieces.h"
 #include "global.h"
 #include "tstring.h"
+#include "eboard.h"
 
 #include "fallback.xpm"
 
@@ -57,13 +58,12 @@ PieceSet::PieceSet(string &name, string &sqname) {
   int i;
 
   // global.debug("PieceSet","PieceSet",name);
-  global.create("PieceSet");
 
   Name=name;
   SqName=sqname;
 
   if (!eff.find(Name,wherever)) {
-    cerr << "<PieceSet::PieceSet> ** file not found: " << name << endl;
+    cerr << _("<PieceSet::PieceSet> ** file not found: ") << name << endl;
     exit(2);
   }
 
@@ -73,7 +73,7 @@ PieceSet::PieceSet(string &name, string &sqname) {
   isrc=gdk_imlib_load_image(cpath);
   if (isrc==0) {
     cerr << "<PieceSet::PieceSet>";
-    cerr << " ** PNG LOAD FAILED: using internal low-res pieceset. It'll look ugly.\n";
+    cerr << _(" ** PNG LOAD FAILED: using internal low-res pieceset. It'll look ugly.\n");
     isrc=FallbackLoad();
   }
 
@@ -82,7 +82,7 @@ PieceSet::PieceSet(string &name, string &sqname) {
   // use squares from other file ?
   if (Name.compare(SqName)) {
     if (!eff.find(SqName, wherever))
-      cerr << "<PieceSet::PieceSet> ** file not found: " << SqName << endl;
+      cerr << _("<PieceSet::PieceSet> ** file not found: ") << SqName << endl;
     else
       loadSquares(wherever);
   }
@@ -139,7 +139,6 @@ PieceSet::~PieceSet() {
       delete(*qi);
     myq.clear();
   }
-  global.destroy("PieceSet");
 }
 
 string & PieceSet::getName() {
@@ -166,7 +165,7 @@ void PieceSet::loadSquares(string &path) {
 
   if (tmp==0) {
     cerr << "<PieceSet::loadSquares>";
-    cerr << " ** PNG LOAD FAILED: using internal low-res pieceset. It'll look ugly.\n";
+    cerr << _(" ** PNG LOAD FAILED: using internal low-res pieceset. It'll look ugly.\n");
     tmp=FallbackLoad();
   }
 
@@ -663,7 +662,7 @@ GdkImlibImage * PieceSet::gimp_scale(GdkImlibImage *gsrc,int nw,int nh) {
 
 
 void PieceSet::calcAlphaMask() {
-  int i,j,c;
+  int c;
   unsigned char r,g,b;
   rgbptr t,am;
   if (alphamask!=0)
@@ -695,11 +694,11 @@ void PieceSet::calcAlphaMask() {
 void PieceSet::drawPiece(piece p, GdkPixmap *dest, GdkGC *gc,
 			 int x, int y) {
   int sx=0,sy=0,S;
-  int i,j,k,ai;
+  int i,j,k=0,ai;
 
   unsigned char buf[3072]; // enough for 1024 x N pieces
-  int bufcount;
-  rgbptr r,q,a;
+  int bufcount=0;
+  rgbptr r,q=0,a;
 
   p&=CUTFLAGS;
   if (p==EMPTY) return;
@@ -780,12 +779,12 @@ void PieceSet::drawOutlinedPiece(piece p,GdkPixmap *dest,GdkGC *gc,
 				 int x,int y,bool white)
 {
   int sx=0,sy=0,S;
-  int i,j,k,ai;
+  int i,j,k=0,ai;
 
   unsigned char buf[3072]; // enough for 1024 x N pieces
   unsigned char outline[3072];
-  int bufcount;
-  rgbptr r,q,a;
+  int bufcount=0;
+  rgbptr r,q=0,a;
 
   p&=CUTFLAGS;
   if (p==EMPTY) return;
@@ -1142,8 +1141,6 @@ VectorPieces::VectorPieces() {
   int i,j;
   orig_sqside=cur_sqside=108;
 
-  global.create("VectorPieces");
-
   np[0]=32; np[1]=67; np[2]=90; np[3]=76; np[4]=65; np[5]=46;
 
   for(i=0;i<6;i++) {
@@ -1194,11 +1191,9 @@ VectorPieces::VectorPieces() {
   rescale(108);
 }
 
-VectorPieces::~VectorPieces() {
-  global.destroy("VectorPieces");
-}
-
-void VectorPieces::drawSquares(GdkPixmap *dest,GdkGC *gc,int sqside, int dx=0, int dy=0) {
+void VectorPieces::drawSquares(GdkPixmap *dest,GdkGC *gc,int sqside, 
+                               int dx, int dy) 
+{
   int i,j;
   for(i=0;i<8;i++)
     for(j=0;j<8;j++) {      
@@ -1214,7 +1209,7 @@ void VectorPieces::drawSquares(GdkPixmap *dest,GdkGC *gc,int sqside, int dx=0, i
 
 void VectorPieces::drawPiece(GdkPixmap *dest,GdkGC *gc,int sqside,
 			      int x,int y,piece p) {
-  int i,j,v;
+  int i,v;
   piece rp,pc;
   //GdkGCValues gcval;
 
