@@ -1,4 +1,4 @@
-/* $Id: protocol.cc,v 1.22 2002/06/14 17:32:57 bergo Exp $ */
+/* $Id: protocol.cc,v 1.25 2003/07/02 23:50:24 bergo Exp $ */
 
 /*
 
@@ -64,10 +64,26 @@ void Protocol::exaBackward(int n) {
 
 }
 
+void Protocol::updateVar(ProtocolVar pv) {
+
+}
+
 void Protocol::sendDrop(piece p,int x,int y) {
   // not all protocols need to support {bug,crazy}house
 }
 
+void Protocol::retractMove() {
+  global.status->setText(_("Sorry, this protocol does not allow to retract a move thru this menu option."), 15);  
+}
+
+// the default implementation just sends the line as is.
+// only the P2P protocol must encode chat lines
+void Protocol::sendUserInput(char *line) {
+  if (global.network)
+    if (global.network->isConnected())
+      global.network->writeLine(line);
+}
+
 void Protocol::refreshSeeks() {
   // not all protocols need to manage a seek table
 }
