@@ -1,4 +1,4 @@
-/* $Id: sound.cc,v 1.19 2003/01/19 19:24:03 bergo Exp $ */
+/* $Id: sound.cc,v 1.22 2003/11/22 04:55:29 bergo Exp $ */
 
 /*
 
@@ -41,9 +41,7 @@
 #include "tstring.h"
 #include "util.h"
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "eboard.h"
 
@@ -312,7 +310,8 @@ char *SoundEvent::getDescription() {
   switch(type) {
   case INT_WAVE:
     sprintf(pvt,_("%d %s to %s, %d Hz for %d msec"),
-	    Count,(Count>1)?_("beeps"):_("beep"),Device,Pitch,Duration);
+	    Count,(Count>1)?_("beeps"):
+                            _("beep"),Device,Pitch,Duration);
     break;
   case EXT_WAVE:
     sprintf(pvt,_("play file %s"),ExtraData);
@@ -481,6 +480,7 @@ SoundEventDialog::SoundEventDialog(SoundEvent *src, SoundEventChangeListener *li
     break;
   case EXT_PROGRAM:
     gtset(GTK_TOGGLE_BUTTON(rd[2]), 1);
+    break;
   case PLAIN_BEEP:
     gtset(GTK_TOGGLE_BUTTON(rd[3]), 1);
     break;
