@@ -1,10 +1,10 @@
-/* $Id: text.cc,v 1.22 2002/04/28 21:04:34 bergo Exp $ */
+/* $Id: text.cc,v 1.33 2003/02/18 02:49:49 bergo Exp $ */
 
 /*
 
     eboard - chess client
     http://eboard.sourceforge.net
-    Copyright (C) 2000-2002 Felipe Paulo Guazzi Bergo
+    Copyright (C) 2000-2003 Felipe Paulo Guazzi Bergo
     bergo@seul.org
 
     This program is free software; you can redistribute it and/or modify
@@ -23,9 +23,7 @@
 
 */
 
-
-
-#include <iostream.h>
+#include <iostream>
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -35,6 +33,7 @@
 #include "global.h"
 #include "tstring.h"
 #include "stl.h"
+#include "eboard.h"
 
 #include "icon-console.xpm"
 #include "addcons.xpm"
@@ -49,17 +48,11 @@ OutputPane::~OutputPane() {
 
 Text::Text() {
   GdkFont *fxd;
-  GtkWidget *hb;
 
-  ScrollBack=-999;
   linecount=0;
-
   LastMatch=-1;
 
-  hb=gtk_hbox_new(FALSE,0);
- 
-  text=gtk_ftext_new(0,0);
-  GTK_FTEXT(text)->col_back=global.Colors.Background;
+  setBG(global.Colors.Background);
 
   fxd=gdk_font_load(global.ConsoleFont);
   if (!fxd)
@@ -72,18 +65,7 @@ Text::Text() {
     exit(69);
   }
 
-  gtk_ftext_set_font(GTK_FTEXT(text),fxd,0);
-
-  gtk_box_pack_start(GTK_BOX(hb),text,TRUE,TRUE,0);
-  gtk_widget_show(text);
-
-  sbar=gtk_vscrollbar_new(GTK_FTEXT(text)->adj);
-
-  gtk_box_pack_start(GTK_BOX(hb),sbar,FALSE,TRUE,0);
-
-  gtk_widget_show(sbar);
-
-  widget=hb;
+  setFont(fxd);
   updateScrollBack();
 }
 
@@ -93,8 +75,6 @@ Text::~Text() {
 
 void Text::findText() {
   SearchTextDialog *st;
-  bool confirmed;
-
   st=new SearchTextDialog(this);
   st->show();
 }
@@ -109,103 +89,77 @@ void Text::findTextNext() {
   bool wrapped = false;
 
   if (SearchString.empty()) {
-    global.status->setText("No previous search.");
+    global.status->setText(_("No previous search."),5);
     return;
   }
 
   if (LastMatch == 0) wrapped = true;
-  if (LastMatch < 0) LastMatch = 0;
+  if (LastMatch < 0)  LastMatch = 0;
 
-  LastMatch = gtk_ftext_find_text_upwards(GTK_FTEXT(text), 
-					  SearchString.c_str(),
-					  0, LastMatch - 1 , TRUE);
+  if (findTextUpward(0,LastMatch - 1,SearchString.c_str())) {
 
-  if (LastMatch < 0) {
-    global.status->setText("Search text not found.");
-  } else {
+    LastMatch = getLastFoundLine();
     global.ebook->goToPageId(-2);
-    gtk_ftext_goto(GTK_FTEXT(text), LastMatch);
-    
-    if (!wrapped) 
-      sprintf(z,"Match Found at Line %d.", LastMatch);
+    gotoLine(LastMatch);
+
+    if (!wrapped)
+      sprintf(z,_("Match Found at Line %d."), LastMatch+1);
     else
-      sprintf(z,"(Wrapped) Match Found at Line %d.", LastMatch);
-    global.status->setText(z);
+      sprintf(z,_("(Wrapped) Match Found at Line %d."), LastMatch+1);
+    global.status->setText(z,10);
+
+  } else {
+
+    LastMatch = -1;
+    global.status->setText(_("Search text not found."),5);
+
   }
 }
 
 void Text::saveBuffer() {
   FileDialog *fd;
 
-  fd=new FileDialog("Save Buffer As...");
+  fd=new FileDialog(_("Save Buffer As..."));
   
   if (fd->run()) {
-    if (gtk_ftext_save_buffer(GTK_FTEXT(text), fd->FileName)) {
-      global.status->setText("Console buffer saved.");
+    if (saveTextBuffer(fd->FileName)) {
+      global.status->setText(_("Console buffer saved."),5);
     } else {
-      global.status->setText("Buffer Save failed.");
+      global.status->setText(_("Buffer Save failed."),10);
     }
   }
 
   delete fd;
 }
 
-void Text::setBackground(int color) {
-  GTK_FTEXT(text)->col_back=color;
-  gtk_widget_queue_resize(text);
-}
-
 void Text::updateFont() {
   GdkFont *fxd;
   fxd=gdk_font_load(global.ConsoleFont);
   if (!fxd) {
-    cerr << "<Text::updateFont> failed to load " << global.ConsoleFont << endl;
+    cerr << _("<Text::updateFont> failed to load ") << global.ConsoleFont << endl;
     return;
   }
-  gtk_ftext_set_font(GTK_FTEXT(text),fxd,0);
-  gtk_widget_queue_resize(text);
+  setFont(fxd);
+  safeSoftRepaint();
 }
 
 void Text::updateScrollBack() {
-  if (ScrollBack!=global.ScrollBack) {
-    ScrollBack=global.ScrollBack;
-    GTK_FTEXT(text)->max_lines=ScrollBack;
-  }
+  setScrollBack(global.ScrollBack);
 }
 
-void Text::pageUp() {
-  GtkAdjustment *adj;
-  gfloat value;
-  adj=GTK_FTEXT(text)->adj;
-  value=adj->value - adj->page_size;
-  if (value<0)
-    value=0;
-  gtk_adjustment_set_value(adj,value);
-}
+void Text::pageUp()   { NText::pageUp(0.75f); }
+void Text::pageDown() { NText::pageDown(0.75f); }
 
-void Text::pageDown() {
-  GtkAdjustment *adj;
-  gfloat value, end;
-  adj=GTK_FTEXT(text)->adj;
-  end = adj->upper - adj->lower - adj->page_size;
-  value=adj->value + adj->page_size;
-  if (value>end)
-    value=end;
-  gtk_adjustment_set_value(adj,value);
-}
-
-void Text::show() {
-  gtk_widget_show(widget);
-}
-
-void Text::append(char *msg,int color,Importance imp=IM_NORMAL) {
+void Text::append(char *msg,int color,Importance imp) {
   if (Filter.accept(msg)) {
     pushLevel(imp);
-    gtk_ftext_append(GTK_FTEXT(text),msg,-1,color);
+    NText::append(msg,strlen(msg),color);
+    contentUpdated();
+    scheduleRepaint(50);
   }
 }
 
-void Text::append(char *msg,char *msg2,int color, Importance imp=IM_NORMAL) {
+void Text::append(char *msg,char *msg2,int color, Importance imp) {
   char *d;
   d=(char *)g_malloc0(strlen(msg)+strlen(msg2)+1);
   strcpy(d,msg);
@@ -214,16 +168,8 @@ void Text::append(char *msg,char *msg2,int color, Importance imp=IM_NORMAL) {
   g_free(d);
 }
 
-void Text::freeze() {
-  //gtk_text_freeze(GTK_TEXT(text));
-}
-
-void Text::thaw() {
-  //gtk_text_thaw(GTK_TEXT(text));
-}
-
-GtkWidget * Text::getTextArea() {
-  return(text);
+void Text::setBackground(int color) {
+  setBG(color);
 }
 
 // -----------------
@@ -253,13 +199,13 @@ void TextSet::removeTarget(Text *target) {
     }
 }
 
-void TextSet::append(char *msg,int color,Importance imp=IM_NORMAL) {
+void TextSet::append(char *msg,int color,Importance imp) {
   list<Text *>::iterator ti;
   for(ti=targets.begin();ti!=targets.end();ti++)
     (*ti)->append(msg,color,imp);
 }
 
-void TextSet::append(char *msg,char *msg2,int color,Importance imp=IM_NORMAL) {
+void TextSet::append(char *msg,char *msg2,int color,Importance imp) {
   list<Text *>::iterator ti;
   for(ti=targets.begin();ti!=targets.end();ti++)
     (*ti)->append(msg,msg2,color,imp);
@@ -314,7 +260,7 @@ DetachedConsole::DetachedConsole(TextSet *yourset, ConsoleListener *cl) {
   // my copy of Stroustrup says one thing about the stringstream class
   // and my libstdc++ says another, better not risk compiling problems,
   // so I'm using C constructs here. Ack.
-  sprintf(tmp,"eboard: Console #%d",ConsoleCount);
+  sprintf(tmp,_("eboard: Console #%d"),ConsoleCount);
   basetitle=tmp;
 
   widget=gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -342,9 +288,9 @@ DetachedConsole::DetachedConsole(TextSet *yourset, ConsoleListener *cl) {
   gtk_box_pack_start(GTK_BOX(vb),hb,FALSE,TRUE,4);
   gtk_box_pack_start(GTK_BOX(hb),inputbox,TRUE,TRUE,4);
 
-  flabel=gtk_label_new("Filter: (none)");
+  flabel=gtk_label_new(_("Filter: (none)"));
 
-  sf=gtk_button_new_with_label("Set Filter...");
+  sf=gtk_button_new_with_label(_("Set Filter..."));
   gtk_box_pack_start(GTK_BOX(hb),flabel,FALSE,FALSE,4);
   gtk_box_pack_start(GTK_BOX(hb),sf,FALSE,FALSE,4);
 
@@ -356,21 +302,16 @@ DetachedConsole::DetachedConsole(TextSet *yourset, ConsoleListener *cl) {
 				    (gchar **) addcons_xpm);
   ae=gtk_pixmap_new(ad,ab);
   gtk_container_add(GTK_CONTAINER(ac),ae);
-  gtk_widget_show(ae);
+  gshow(ae);
 
   gtk_box_pack_start(GTK_BOX(hb),ac,FALSE,FALSE,4);
 
-  gtk_widget_show(inputbox);
-  gtk_widget_show(sf);
-  gtk_widget_show(flabel);
-  gtk_widget_show(ac);
-  gtk_widget_show(hb);
-  gtk_widget_show(vb);
+  Gtk::show(inputbox,sf,flabel,ac,hb,vb,0);
   inner->show();
 
   yourset->addTarget(inner);
 
-  setIcon(icon_console_xpm,"Console");
+  setIcon(icon_console_xpm,_("Console"));
 
   gtk_signal_connect(GTK_OBJECT(widget),"delete_event",
 		     GTK_SIGNAL_FUNC(detached_delete),(gpointer)this);
@@ -394,7 +335,7 @@ DetachedConsole::DetachedConsole(TextSet *yourset, ConsoleListener *cl) {
 void DetachedConsole::clone() {
   DetachedConsole *dc;
   dc=new DetachedConsole(myset,0);
-  global.input->peekKeys(dc->widget);
+  //global.input->peekKeys(dc->widget);
   dc->show();
 }
 
@@ -439,10 +380,10 @@ void DetachedConsole::setFilter(char *s) {
 
 void DetachedConsole::updateFilterLabel() {
   char z[256];
-  strcpy(z,"Filter: ");
+  strcpy(z,_("Filter: "));
   strcat(z,inner->Filter.getString());
   if (strlen(z)==8)
-    strcat(z,"(none)");
+    strcat(z,_("(none)"));
   gtk_label_set_text(GTK_LABEL(flabel),z);
   gtk_widget_queue_resize(flabel);
 }
@@ -489,6 +430,8 @@ int dc_input_key_press (GtkWidget * wid, GdkEventKey * evt,
   case GDK_Page_Down:
     me->inner->pageDown();
     return 1;
+  default:
+    return(global.input->keyPressed(evt->keyval, evt->state));
   }
   return 0;
 }
@@ -520,7 +463,7 @@ void dc_new_console(GtkWidget *w,gpointer data) {
 // --- set filter... dialog
 
 TextFilterDialog::TextFilterDialog(Text *target,GtkWidget *label2update) 
-    : ModalDialog("Set Filter")
+    : ModalDialog(N_("Set Filter"))
 {
   GtkWidget *v,*h,*lb,*lb2,*hs,*bb,*ok,*can;
 
@@ -531,13 +474,13 @@ TextFilterDialog::TextFilterDialog(Text *target,GtkWidget *label2update)
   gtk_container_add(GTK_CONTAINER(widget),v);
 
   h=gtk_hbox_new(FALSE,4);
-  lb=gtk_label_new("Match Pattern: ");
-  lb2=gtk_label_new("Only lines that match the above pattern will be added\n"\
+  lb=gtk_label_new(_("Match Pattern: "));
+  lb2=gtk_label_new(_("Only lines that match the above pattern will be added\n"\
 		    "to this text pane. Patterns can be OR'ed with the | (pipe)\n"\
 		    "character. A * (star) can be used to match anything.\n"\
 		    "Examples:\n"\
 		    "'(20)|(22)' shows only lines from channels 20 and 22\n"\
-		    "'blik * bored' shows lines containing 'blik '(...)' bored'.");
+		    "'blik * bored' shows lines containing 'blik '(...)' bored'."));
   gtk_label_set_justify(GTK_LABEL(lb2),GTK_JUSTIFY_LEFT);
 
   gtk_box_pack_start(GTK_BOX(h),lb,FALSE,FALSE,2);
@@ -555,24 +498,15 @@ TextFilterDialog::TextFilterDialog(Text *target,GtkWidget *label2update)
   gtk_button_box_set_spacing(GTK_BUTTON_BOX(bb), 5);
   gtk_box_pack_start(GTK_BOX(v),bb,FALSE,FALSE,2);
 
-  ok=gtk_button_new_with_label("Ok");
+  ok=gtk_button_new_with_label(_("Ok"));
   GTK_WIDGET_SET_FLAGS(ok,GTK_CAN_DEFAULT);
-  can=gtk_button_new_with_label("Cancel");
+  can=gtk_button_new_with_label(_("Cancel"));
   GTK_WIDGET_SET_FLAGS(can,GTK_CAN_DEFAULT);
   gtk_box_pack_start(GTK_BOX(bb),ok,TRUE,TRUE,0);
   gtk_box_pack_start(GTK_BOX(bb),can,TRUE,TRUE,0);
   gtk_widget_grab_default(ok);
 
-  gtk_widget_show(ok);
-  gtk_widget_show(can);
-  gtk_widget_show(bb);
-  gtk_widget_show(hs);
-  gtk_widget_show(lb2);
-  gtk_widget_show(lb);
-  gtk_widget_show(pattern);
-  gtk_widget_show(h);
-  gtk_widget_show(v);
-
+  Gtk::show(ok,can,bb,hs,lb2,lb,pattern,h,v,0);
   gtk_entry_set_text(GTK_ENTRY(pattern),obj->Filter.getString());
 
   setDismiss(GTK_OBJECT(can),"clicked");
@@ -590,10 +524,10 @@ void tfd_ok(GtkWidget *w, gpointer data)
   me->obj->Filter.set(gtk_entry_get_text(GTK_ENTRY(me->pattern)));
 
   if (me->ulabel) {
-    strcpy(z,"Filter: ");
+    strcpy(z,_("Filter: "));
     strcat(z,me->obj->Filter.getString());
     if (strlen(z)==8)
-      strcat(z,"(none)");
+      strcat(z,_("(none)"));
     gtk_label_set_text(GTK_LABEL(me->ulabel),z);
     gtk_widget_queue_resize(me->ulabel);
   }
@@ -685,7 +619,7 @@ void TextFilter::cleanUp() {
 // SearchTextDialog and its interface
 
 SearchTextDialog::SearchTextDialog(Searchable *src) 
-  : ModalDialog("Search Text")
+  : ModalDialog(N_("Search Text"))
 {
   GtkWidget *v, *h, *lb, *hs, *bb, *ok, *can;
 
@@ -695,7 +629,7 @@ SearchTextDialog::SearchTextDialog(Searchable *src)
   gtk_container_add(GTK_CONTAINER(widget),v);
 
   h=gtk_hbox_new(FALSE,4);
-  lb=gtk_label_new("Search for: ");
+  lb=gtk_label_new(_("Search for: "));
 
   gtk_box_pack_start(GTK_BOX(h),lb,FALSE,FALSE,2);
   text=gtk_entry_new();
@@ -711,23 +645,15 @@ SearchTextDialog::SearchTextDialog(Searchable *src)
   gtk_button_box_set_spacing(GTK_BUTTON_BOX(bb), 5);
   gtk_box_pack_start(GTK_BOX(v),bb,FALSE,FALSE,2);
 
-  ok=gtk_button_new_with_label("Ok");
+  ok=gtk_button_new_with_label(_("Ok"));
   GTK_WIDGET_SET_FLAGS(ok,GTK_CAN_DEFAULT);
-  can=gtk_button_new_with_label("Cancel");
+  can=gtk_button_new_with_label(_("Cancel"));
   GTK_WIDGET_SET_FLAGS(can,GTK_CAN_DEFAULT);
   gtk_box_pack_start(GTK_BOX(bb),ok,TRUE,TRUE,0);
   gtk_box_pack_start(GTK_BOX(bb),can,TRUE,TRUE,0);
   gtk_widget_grab_default(ok);
 
-  gtk_widget_show(ok);
-  gtk_widget_show(can);
-  gtk_widget_show(bb);
-  gtk_widget_show(hs);
-  gtk_widget_show(lb);
-  gtk_widget_show(text);
-  gtk_widget_show(h);
-  gtk_widget_show(v);
-
+  Gtk::show(ok,can,bb,hs,lb,text,h,v,0);
   gtk_entry_set_text(GTK_ENTRY(text), searchable->SearchString.c_str());
 
   setDismiss(GTK_OBJECT(can),"clicked");
